==> ejc-analysis-impl-3.0.0-20230720.060227-90-sources.jar: com/ejianc/business/analysis/bean/SettleEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分供方结算情况汇总表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_analysis_settle")
public class SettleEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_status")
    private Integer projectStatus; // 项目状态
    @TableField(value="reporting_month")
    private String reportingMonth; // 报表日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="code")
    private String code; // 费用编码
    @TableField(value="project_create_time")
    private Date projectCreateTime; // 项目创建日期
    @TableField(value="cost_analysis_create_time")
    private Date costAnalysisCreateTime; // 月度分析报告创建时间
    @TableField(value="org_status_order")
    private Integer orgStatusOrder; // 二级组织排序
    @TableField(value="contract_status_order")
    private Integer contractStatusOrder; // 分供合同类型
    @TableField(value="contract_num")
    private BigDecimal contractNum; // 分供合同数量
    @TableField(value="settle_rate")
    private BigDecimal settleRate; // 结算完成率
    @TableField(value="settle_mny")
    private BigDecimal settleMny; // 已办理结算金额
    @TableField(value="claim_mny")
    private BigDecimal claimMny; // 已确认变洽签、索赔金额
    @TableField(value="claim_rate")
    private BigDecimal claimRate; // 变洽签金额占劳务、专业比
    @TableField(value="yf_mny")
    private BigDecimal yfMny; // 应付金额
    @TableField(value="pay_mny")
    private BigDecimal payMny; // 已付金额
    @TableField(value="yfwf_mny")
    private BigDecimal yfwfMny; // 应付未付金额
    @TableField(value="contract_status_name")
    private String contractStatusName; // 分供合同类型名称
    @TableField(value="lw_settle_mny")
    private BigDecimal lwSettleMny; // 已结算劳务分包金额
    @TableField(value="lw_pay_mny")
    private BigDecimal lwPayMny; // 已付款劳务分包金额
    @TableField(value="lw_rate")
    private BigDecimal lwRate; // 劳务分包付款率
    @TableField(value="zy_settle_mny")
    private BigDecimal zySettleMny; // 已结算专业分包金额
    @TableField(value="zy_pay_mny")
    private BigDecimal zyPayMny; // 已付款专业分包金额
    @TableField(value="zy_rate")
    private BigDecimal zyRate; // 专业分包付款率
    @TableField(value="yjyj_num")
    private BigDecimal yjyjNum; // 已竣已结数量
    @TableField(value="yjwj_num")
    private BigDecimal yjwjNum; // 已竣未结数量

    public BigDecimal getYjyjNum() {
        return yjyjNum;
    }

    public void setYjyjNum(BigDecimal yjyjNum) {
        this.yjyjNum = yjyjNum;
    }

    public BigDecimal getYjwjNum() {
        return yjwjNum;
    }

    public void setYjwjNum(BigDecimal yjwjNum) {
        this.yjwjNum = yjwjNum;
    }

    public BigDecimal getLwSettleMny() {
        return lwSettleMny;
    }

    public void setLwSettleMny(BigDecimal lwSettleMny) {
        this.lwSettleMny = lwSettleMny;
    }

    public BigDecimal getLwPayMny() {
        return lwPayMny;
    }

    public void setLwPayMny(BigDecimal lwPayMny) {
        this.lwPayMny = lwPayMny;
    }

    public BigDecimal getLwRate() {
        return lwRate;
    }

    public void setLwRate(BigDecimal lwRate) {
        this.lwRate = lwRate;
    }

    public BigDecimal getZySettleMny() {
        return zySettleMny;
    }

    public void setZySettleMny(BigDecimal zySettleMny) {
        this.zySettleMny = zySettleMny;
    }

    public BigDecimal getZyPayMny() {
        return zyPayMny;
    }

    public void setZyPayMny(BigDecimal zyPayMny) {
        this.zyPayMny = zyPayMny;
    }

    public BigDecimal getZyRate() {
        return zyRate;
    }

    public void setZyRate(BigDecimal zyRate) {
        this.zyRate = zyRate;
    }

    public String getContractStatusName() {
        return contractStatusName;
    }

    public void setContractStatusName(String contractStatusName) {
        this.contractStatusName = contractStatusName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    public Integer getContractStatusOrder() {
        return contractStatusOrder;
    }

    public void setContractStatusOrder(Integer contractStatusOrder) {
        this.contractStatusOrder = contractStatusOrder;
    }
    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }
    public BigDecimal getSettleRate() {
        return settleRate;
    }

    public void setSettleRate(BigDecimal settleRate) {
        this.settleRate = settleRate;
    }
    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }
    public BigDecimal getClaimMny() {
        return claimMny;
    }

    public void setClaimMny(BigDecimal claimMny) {
        this.claimMny = claimMny;
    }
    public BigDecimal getClaimRate() {
        return claimRate;
    }

    public void setClaimRate(BigDecimal claimRate) {
        this.claimRate = claimRate;
    }
    public BigDecimal getYfMny() {
        return yfMny;
    }

    public void setYfMny(BigDecimal yfMny) {
        this.yfMny = yfMny;
    }
    public BigDecimal getPayMny() {
        return payMny;
    }

    public void setPayMny(BigDecimal payMny) {
        this.payMny = payMny;
    }
    public BigDecimal getYfwfMny() {
        return yfwfMny;
    }

    public void setYfwfMny(BigDecimal yfwfMny) {
        this.yfwfMny = yfwfMny;
    }
    
}

==> ejc-analysis-impl-3.0.0-20241017.064316-257-sources.jar: com/ejianc/business/analysis/bean/SettleEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分供方结算情况汇总表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_analysis_settle")
public class SettleEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_status")
    private Integer projectStatus; // 项目状态
    @TableField(value="reporting_month")
    private String reportingMonth; // 报表日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="code")
    private String code; // 费用编码
    @TableField(value="project_create_time")
    private Date projectCreateTime; // 项目创建日期
    @TableField(value="cost_analysis_create_time")
    private Date costAnalysisCreateTime; // 月度分析报告创建时间
    @TableField(value="org_status_order")
    private Integer orgStatusOrder; // 二级组织排序
    @TableField(value="contract_status_order")
    private Integer contractStatusOrder; // 分供合同类型
    @TableField(value="contract_num")
    private BigDecimal contractNum; // 分供合同数量
    @TableField(value="settle_rate")
    private BigDecimal settleRate; // 结算完成率
    @TableField(value="settle_mny")
    private BigDecimal settleMny; // 已办理结算金额
    @TableField(value="claim_mny")
    private BigDecimal claimMny; // 已确认变洽签、索赔金额
    @TableField(value="claim_rate")
    private BigDecimal claimRate; // 变洽签金额占劳务、专业比
    @TableField(value="yf_mny")
    private BigDecimal yfMny; // 应付金额
    @TableField(value="pay_mny")
    private BigDecimal payMny; // 已付金额
    @TableField(value="yfwf_mny")
    private BigDecimal yfwfMny; // 应付未付金额
    @TableField(value="contract_status_name")
    private String contractStatusName; // 分供合同类型名称
    @TableField(value="lw_settle_mny")
    private BigDecimal lwSettleMny; // 已结算劳务分包金额
    @TableField(value="lw_pay_mny")
    private BigDecimal lwPayMny; // 已付款劳务分包金额
    @TableField(value="lw_rate")
    private BigDecimal lwRate; // 劳务分包付款率
    @TableField(value="zy_settle_mny")
    private BigDecimal zySettleMny; // 已结算专业分包金额
    @TableField(value="zy_pay_mny")
    private BigDecimal zyPayMny; // 已付款专业分包金额
    @TableField(value="zy_rate")
    private BigDecimal zyRate; // 专业分包付款率
    @TableField(value="yjyj_num")
    private BigDecimal yjyjNum; // 已竣已结数量
    @TableField(value="yjwj_num")
    private BigDecimal yjwjNum; // 已竣未结数量
    @TableField(value="short_name")
    private String shortName;//组织简称
    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }
    public BigDecimal getYjyjNum() {
        return yjyjNum;
    }

    public void setYjyjNum(BigDecimal yjyjNum) {
        this.yjyjNum = yjyjNum;
    }

    public BigDecimal getYjwjNum() {
        return yjwjNum;
    }

    public void setYjwjNum(BigDecimal yjwjNum) {
        this.yjwjNum = yjwjNum;
    }

    public BigDecimal getLwSettleMny() {
        return lwSettleMny;
    }

    public void setLwSettleMny(BigDecimal lwSettleMny) {
        this.lwSettleMny = lwSettleMny;
    }

    public BigDecimal getLwPayMny() {
        return lwPayMny;
    }

    public void setLwPayMny(BigDecimal lwPayMny) {
        this.lwPayMny = lwPayMny;
    }

    public BigDecimal getLwRate() {
        return lwRate;
    }

    public void setLwRate(BigDecimal lwRate) {
        this.lwRate = lwRate;
    }

    public BigDecimal getZySettleMny() {
        return zySettleMny;
    }

    public void setZySettleMny(BigDecimal zySettleMny) {
        this.zySettleMny = zySettleMny;
    }

    public BigDecimal getZyPayMny() {
        return zyPayMny;
    }

    public void setZyPayMny(BigDecimal zyPayMny) {
        this.zyPayMny = zyPayMny;
    }

    public BigDecimal getZyRate() {
        return zyRate;
    }

    public void setZyRate(BigDecimal zyRate) {
        this.zyRate = zyRate;
    }

    public String getContractStatusName() {
        return contractStatusName;
    }

    public void setContractStatusName(String contractStatusName) {
        this.contractStatusName = contractStatusName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    public Integer getContractStatusOrder() {
        return contractStatusOrder;
    }

    public void setContractStatusOrder(Integer contractStatusOrder) {
        this.contractStatusOrder = contractStatusOrder;
    }
    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }
    public BigDecimal getSettleRate() {
        return settleRate;
    }

    public void setSettleRate(BigDecimal settleRate) {
        this.settleRate = settleRate;
    }
    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }
    public BigDecimal getClaimMny() {
        return claimMny;
    }

    public void setClaimMny(BigDecimal claimMny) {
        this.claimMny = claimMny;
    }
    public BigDecimal getClaimRate() {
        return claimRate;
    }

    public void setClaimRate(BigDecimal claimRate) {
        this.claimRate = claimRate;
    }
    public BigDecimal getYfMny() {
        return yfMny;
    }

    public void setYfMny(BigDecimal yfMny) {
        this.yfMny = yfMny;
    }
    public BigDecimal getPayMny() {
        return payMny;
    }

    public void setPayMny(BigDecimal payMny) {
        this.payMny = payMny;
    }
    public BigDecimal getYfwfMny() {
        return yfwfMny;
    }

    public void setYfwfMny(BigDecimal yfwfMny) {
        this.yfwfMny = yfwfMny;
    }
    
}
